package com.pokkt.demo.fragments;

import android.os.Bundle;
import android.text.format.DateUtils;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import android.widget.Button;
import android.widget.TextView;

import com.pokkt.PokktAds;
import com.pokkt.ad.demo.BuildConfig;
import com.pokkt.demo.PokktKotlinPluginKt;
import com.pokkt.demo.utility.FragmentTransactionManager;
import com.pokkt.ad.demo.R;
import com.pokkt.demo.utility.Storage;

import java.util.Calendar;

public class PokktAdTypeFragment extends BaseFragment {

    // ui
    private TextView txtTestRelease, txtFrameworkName, txtSDKVersion;
    private Button btnAdTypeFullScreen, btnAdTypeBanner, btnAdTypeMore, btnAdTypeNative, btnPlayByTag;

    public PokktAdTypeFragment() {
        // Required empty public constructor
    }

    @Override
    public void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        // getArguments here
    }

    @Override
    public View onCreateView(LayoutInflater inflater, ViewGroup container,
                             Bundle savedInstanceState) {

        View rootView = inflater.inflate(R.layout.fragment_pokkt_ad_type, container, false);

        //version info
        txtTestRelease = (TextView) findView(rootView, R.id.txt_test_release_version);
        txtFrameworkName = (TextView) findView(rootView, R.id.txt_framework_name);
        txtSDKVersion = (TextView) findView(rootView, R.id.txt_sdk_version);

        //Fullscreen
        btnAdTypeFullScreen = (Button) findView(findView(rootView, R.id.btn_ad_type_fullscreen), R.id.button);
        btnAdTypeFullScreen.setContentDescription(getString(R.string.test_FullScreenBtn));

        //banner
        btnAdTypeBanner = (Button) findView(findView(rootView, R.id.btn_ad_type_banner), R.id.button);
        btnAdTypeBanner.setContentDescription(getString(R.string.test_bannerBtn));

        //outstream
        btnAdTypeNative = (Button) findView(findView(rootView, R.id.btn_ad_type_native), R.id.button);
        btnAdTypeNative.setContentDescription(getString(R.string.test_NativeBtn));

        // play by tag
        btnPlayByTag = (Button) findView(findView(rootView, R.id.btn_ad_type_tag), R.id.button);
        if(!BuildConfig.DEBUG) {
            rootView.findViewById(R.id.btn_ad_type_tag).setVisibility(View.GONE);
        }

        //more == settings
        btnAdTypeMore = (Button) findView(findView(rootView, R.id.btn_ad_type_more), R.id.button);
        btnAdTypeMore.setContentDescription(getString(R.string.test_SettingBtn));

        return rootView;
    }


    @Override
    public void onViewCreated(View view, Bundle savedInstanceState) {
        super.onViewCreated(view, savedInstanceState);

        // setup data

        // txtTestRelease
        if (getResources().getBoolean(R.bool.is_test_release)) {
            txtTestRelease.setVisibility(View.VISIBLE);
            txtTestRelease.setText(String.format(getString(R.string.txt_test_release_version), getString(R.string.test_release_version)));
            setFont(txtTestRelease);

            txtFrameworkName.setVisibility(View.VISIBLE);
            txtFrameworkName.setText(getString(R.string.framework_name));
            setFont(txtFrameworkName);
        }

        // txtSDKVersion
        long buildTime = BuildConfig.TIMESTAMP;
        Calendar cal = Calendar.getInstance();
        cal.setTimeInMillis(buildTime);
        String date = cal.get(Calendar.DAY_OF_MONTH) + "-"
                +  (cal.get(Calendar.MONTH) + 1) + "-"
                +  cal.get(Calendar.YEAR) + " ,"
                +  cal.get(Calendar.HOUR) + ":"
                +  cal.get(Calendar.MINUTE) + " "
                +  DateUtils.getAMPMString(cal.get(Calendar.AM_PM));

        if(Storage.isKotlin) {
            txtSDKVersion.setText(String.format(getString(R.string.txt_sdk_version), PokktKotlinPluginKt.getSDKVersion() + " " + date));
        } else {
            txtSDKVersion.setText(String.format(getString(R.string.txt_sdk_version), PokktAds.getSDKVersion() + " " + date));
        }
        setFont(txtSDKVersion);

        // btnAdTypeFullScreen
        btnAdTypeFullScreen.setText(getString(R.string.txt_btn_ad_type_fullscreen));
        setFont(btnAdTypeFullScreen);
        btnAdTypeFullScreen.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v) {
                openFullScreenAdsShowcase();
            }
        });
        // btnAdTypeBanner
        btnAdTypeBanner.setText(getString(R.string.txt_btn_ad_type_banner));
        setFont(btnAdTypeBanner);
        btnAdTypeBanner.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v) {
                openBannerAdsShowcase();
            }
        });
        // btnAdTypeOutStream
        btnAdTypeNative.setText(getString(R.string.txt_btn_ad_type_native));
        setFont(btnAdTypeNative);
        btnAdTypeNative.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v) {
                openNativeAdsShowcase();
            }
        });
        //btnPlayByTag
        btnPlayByTag.setText(getString(R.string.txt_btn_play_by_tag));
        setFont(btnPlayByTag);
        btnPlayByTag.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v) {
                openPlayWithTag();
            }
        });
        // btnAdTypeMore
        btnAdTypeMore.setText(getString(R.string.txt_btn_more));
        setFont(btnAdTypeMore);
        btnAdTypeMore.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v) {
                openMoreSettings();
            }
        });

    }

    private void openFullScreenAdsShowcase() {
        PokktFullScreenFragment fragment = new PokktFullScreenFragment();
        FragmentTransactionManager.addFragmentWithTag(getActivity(), R.id.container, fragment, PokktFullScreenFragment.class.getSimpleName());
        //PokktAds.InGameAd.fetchAssets("screenName");
    }

    private void openBannerAdsShowcase() {
        PokktBannerFragment fragment = new PokktBannerFragment();
        FragmentTransactionManager.addFragmentWithTag(getActivity(), R.id.container, fragment, PokktBannerFragment.class.getSimpleName());
    }

    private void openNativeAdsShowcase() {
        PokktNativeAdFragment fragment = new PokktNativeAdFragment();
        FragmentTransactionManager.addFragmentWithTag(getActivity(), R.id.container, fragment, PokktNativeAdFragment.class.getSimpleName());
    }

    private void openPlayWithTag() {
        try {
            if (BuildConfig.DEBUG) {
                Class clazz = Class.forName("com.pokkt.demo.fragments.PlayWithTagFragment");
                FragmentTransactionManager.addFragmentWithTag(getActivity(), R.id.container, (BaseFragment) clazz.newInstance(), "PlayWithTagFragment");
            }
        } catch (ClassNotFoundException e) {
            e.printStackTrace();
        } catch (IllegalAccessException e) {
            e.printStackTrace();
        } catch (java.lang.InstantiationException e) {
            e.printStackTrace();
        }
    }

    private void openMoreSettings() {
        PokktSettingsFragment fragment = new PokktSettingsFragment();
        FragmentTransactionManager.addFragmentWithTag(getActivity(), R.id.container, fragment, PokktSettingsFragment.class.getSimpleName());
    }

    @Override
    public void onDestroy() {
        getActivity().finish();
        super.onDestroy();
    }
}
