package com.pokkt.demo.fragments.Wrapper.admob.recyclerlist;

import android.os.Bundle;
import android.util.Log;
import android.view.View;

import androidx.appcompat.app.AppCompatActivity;
import androidx.recyclerview.widget.LinearLayoutManager;
import androidx.recyclerview.widget.RecyclerView;

import com.google.android.gms.ads.AdListener;
import com.google.android.gms.ads.AdLoader;
import com.google.android.gms.ads.AdRequest;
import com.google.android.gms.ads.MobileAds;
import com.google.android.gms.ads.formats.UnifiedNativeAd;
import com.pokkt.ad.demo.R;

import java.util.ArrayList;
import java.util.List;

public class AdMobNativeRecyclerActivity extends AppCompatActivity {

    private AdLoader adLoader;
    private List<Object> mRecyclerViewItems = new ArrayList<>();
    private List<UnifiedNativeAd> mNativeAds = new ArrayList<>();
    private AdMobNativeRecyclerViewAdapter adapter;
    private String adunit;

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.native_recycler);

        adunit = getIntent().getStringExtra("AdUnit");

        //MobileAds.initialize(this, getString(R.string.admob_app_id));

        if (savedInstanceState == null) {
            addListItems();
            RecyclerView mRecyclerView = findViewById(R.id.recycler_view);
            mRecyclerView.setHasFixedSize(true);

            RecyclerView.LayoutManager layoutManager = new LinearLayoutManager(this);
            mRecyclerView.setLayoutManager(layoutManager);
            adapter = new AdMobNativeRecyclerViewAdapter(this,mRecyclerViewItems);
            mRecyclerView.setAdapter(adapter);
            loadNativeAds();
            findViewById(R.id.refresh).setVisibility(View.GONE);
        }
    }

    private void insertAdsInList() {
        if (mNativeAds.size() <= 0) {
            return;
        }

        int offset = (mRecyclerViewItems.size() / mNativeAds.size()) + 1;
        int index = 0;
        for (UnifiedNativeAd ad : mNativeAds) {
            mRecyclerViewItems.add(index, ad);
            index = index + offset;
        }
        adapter.notifyDataSetChanged();
    }

private void loadNativeAds() {

    AdLoader.Builder builder = new AdLoader.Builder(this, adunit);
    adLoader = builder.forUnifiedNativeAd(
        new UnifiedNativeAd.OnUnifiedNativeAdLoadedListener() {
            @Override
            public void onUnifiedNativeAdLoaded(UnifiedNativeAd unifiedNativeAd) {
                // A native ad loaded successfully, check if the ad loader has finished loading
                // and if so, insert the ads into the list.
                mNativeAds.add(unifiedNativeAd);
                if (!adLoader.isLoading()) {
                    insertAdsInList();
                }
            }
        }).withAdListener(
        new AdListener() {
            @Override
            public void onAdFailedToLoad(int errorCode) {
                // A native ad failed to load, check if the ad loader has finished loading
                // and if so, insert the ads into the list.
                Log.e("AdMobNativeRecycler", "The previous native ad failed to load. Attempting to" + " load another.");
                if (!adLoader.isLoading()) {
                    insertAdsInList();
                }
            }
        }).build();

    // Load the Native ads.
    adLoader.loadAd(new AdRequest.Builder().build());
}

    private void addListItems() {
        for (int i = 1; i < 20; ++i) {
            String itemName = "Name : " + i;
            String itemDescription = "Description : " + i;

            ListItem item = new ListItem(itemName,itemDescription);
            mRecyclerViewItems.add(item);
        }
    }
}
