package com.pokkt.demo.fragments.Wrapper.nativead.recyclerlist;

import android.os.Bundle;
import android.view.View;
import android.widget.Button;

import androidx.appcompat.app.AppCompatActivity;
import androidx.recyclerview.widget.LinearLayoutManager;
import androidx.recyclerview.widget.RecyclerView;

import com.mopub.common.MoPub;
import com.mopub.common.SdkConfiguration;
import com.mopub.common.logging.MoPubLog;
import com.mopub.nativeads.MediaViewBinder;
import com.mopub.nativeads.MoPubNativeAdLoadedListener;
import com.mopub.nativeads.MoPubRecyclerAdapter;
import com.mopub.nativeads.MoPubVideoNativeAdRenderer;
import com.pokkt.PokktAds;
import com.pokkt.ad.demo.R;
import com.pokkt.demo.fragments.Wrapper.admob.recyclerlist.ListItem;

import java.util.ArrayList;
import java.util.List;

public class MoPubNativeRecyclerActivity extends AppCompatActivity {

    private List<Object> mRecyclerViewItems = new ArrayList<>();

    private String adunit;
    private MoPubRecyclerAdapter myMoPubAdapter;
    private MoPubNativeRecyclerViewAdapter adapter;
    private RecyclerView mRecyclerView;

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.native_recycler);
        setTitle("MoPub Native List");
        adunit = getIntent().getStringExtra("AdUnit");

        if (savedInstanceState == null) {
            addListItems();
            mRecyclerView = findViewById(R.id.recycler_view);
            mRecyclerView.setHasFixedSize(true);

            RecyclerView.LayoutManager layoutManager = new LinearLayoutManager(this);
            mRecyclerView.setLayoutManager(layoutManager);

            adapter = new MoPubNativeRecyclerViewAdapter(mRecyclerViewItems);
            loadNativeAds();

            Button refresh = findViewById(R.id.refresh);
            refresh.setOnClickListener(new View.OnClickListener() {
                @Override
                public void onClick(View v) {
                    if(myMoPubAdapter != null) {
                        myMoPubAdapter.refreshAds(adunit);
                    }
                }
            });
        }
    }

    private void loadNativeAds() {
        if (!MoPub.isSdkInitialized()) {
            SdkConfiguration.Builder configurationBuilder = new SdkConfiguration.Builder(adunit);
            configurationBuilder.withLogLevel(MoPubLog.LogLevel.DEBUG);
            MoPub.initializeSdk(this, configurationBuilder.build(), null);
        }

//                MoPubNative moPubNative = new MoPubNative(getActivity(), "11a17b188668469fb0412708c3d16813 ", moPubNativeNetworkListener);
//                MoPubNative moPubNative = new MoPubNative(getActivity(), "02a2d288d2674ad09f3241d46a44356e ", moPubNativeNetworkListener);

        MediaViewBinder mediaViewBinder = new MediaViewBinder.Builder(R.layout.mopub_native_ad_layout)
                .mediaLayoutId(R.id.native_ad_media_layout)
                .iconImageId(R.id.native_ad_icon_image)
                .titleId(R.id.native_ad_title)
                .textId(R.id.native_ad_text)
                .build();


        // Pass the recycler Adapter your original adapter.
        myMoPubAdapter = new MoPubRecyclerAdapter(this, adapter);
        // Create an ad renderer and view binder that describe your native ad layout.
        MoPubVideoNativeAdRenderer moPubVideoNativeAdRenderer = new MoPubVideoNativeAdRenderer(mediaViewBinder);

        myMoPubAdapter.registerAdRenderer(moPubVideoNativeAdRenderer);

        // Set up the RecyclerView and start loading ads
        mRecyclerView.setAdapter(myMoPubAdapter);
        myMoPubAdapter.setAdLoadedListener(new MoPubNativeAdLoadedListener() {
            @Override
            public void onAdLoaded(int position) {
                PokktAds.Debugging.showToast(MoPubNativeRecyclerActivity.this, "Ad Displayed " + position);
            }

            @Override
            public void onAdRemoved(int position) {
                PokktAds.Debugging.showToast(MoPubNativeRecyclerActivity.this, "Ad failed to load: " + position);
            }
        });
        myMoPubAdapter.loadAds(adunit);
    }

    private void addListItems() {
        for (int i = 1; i < 20; ++i) {
            String itemName = "Name : " + i;
            String itemDescription = "Description : " + i;
            ListItem item = new ListItem(itemName, itemDescription);
            mRecyclerViewItems.add(item);
        }
    }

    @Override
    public void onDestroy() {
        myMoPubAdapter.destroy();
        super.onDestroy();
    }
}
