package com.pokkt.demo.utility;

import android.content.Context;

import androidx.fragment.app.Fragment;
import androidx.fragment.app.FragmentActivity;
import androidx.fragment.app.FragmentManager;

/**
 * Created by abhinav-rathore on 29-04-2015.
 */
public class FragmentTransactionManager {

    public static void addFragmentWithTag(FragmentActivity mAct, int containerID, Fragment frag, String fragmentTag) {
        FragmentManager fragmentManager = mAct.getSupportFragmentManager();
        fragmentManager.beginTransaction()
                .add(containerID, frag, fragmentTag)
                .addToBackStack(fragmentTag)
                .commitAllowingStateLoss();
    }

    public static void addFragmentWithoutTag(FragmentActivity mAct, int containerID, Fragment frag) {
        FragmentManager fragmentManager = mAct.getSupportFragmentManager();
        fragmentManager.beginTransaction()
                .add(containerID, frag)
                .addToBackStack(null)
                .commitAllowingStateLoss();
    }

    public static void replaceFragmentWithTag(FragmentActivity mAct, int containerID, Fragment frag, String fragmentTag) {
        FragmentManager fragmentManager = mAct.getSupportFragmentManager();
        if (fragmentManager.getBackStackEntryCount() > 0) {
            fragmentManager.popBackStackImmediate();
        }
        fragmentManager.beginTransaction()
                .replace(containerID, frag, fragmentTag)
                .addToBackStack(fragmentTag)
                .commitAllowingStateLoss();
    }

    public static void replaceFragmentWithoutTag(FragmentActivity mAct, int containerID, Fragment frag) {
        FragmentManager fragmentManager = mAct.getSupportFragmentManager();
        fragmentManager.beginTransaction()
                .addToBackStack(null)
                .replace(containerID, frag)
                .commitAllowingStateLoss();
    }

    public static void popFragmentThroughId(FragmentActivity mAct, int containerID, Fragment frag) {
        FragmentManager fragmentManager = mAct.getSupportFragmentManager();
        fragmentManager.popBackStack(containerID, FragmentManager.POP_BACK_STACK_INCLUSIVE);
    }

    public static void popFragmentThroughTag(FragmentActivity mAct, String fragmentName, Fragment frag) {
        FragmentManager fragmentManager = mAct.getSupportFragmentManager();
        fragmentManager.popBackStack(fragmentName, FragmentManager.POP_BACK_STACK_INCLUSIVE);
    }


    public static Fragment getFragmentThroughTag(FragmentActivity mAct, String fragmentTag) {
        return  mAct.getSupportFragmentManager().findFragmentByTag(fragmentTag);
    }


    public static Fragment getActiveFragment(Context context, int containerID) {
        return ((FragmentActivity) context).getSupportFragmentManager().findFragmentById(containerID);

    }

    public  static void removeAllFragments(FragmentActivity activity){
        FragmentManager fragmentManager = activity.getSupportFragmentManager();
        int backStackCount =fragmentManager.getBackStackEntryCount();
        for(int i = backStackCount ; i > 0; i--){
            fragmentManager.popBackStackImmediate();
        }

    }
}
